'use strict';
import {genUpToken} from "@/dome/base/scripts/qiniu";
import {mapActions} from "vuex";

function stringToNumber(str) {
  let result = 0;
  let len = str.length;
  for (let i = 0; i < len; i++) {
    result = result + str.charCodeAt(i) + i;
  }
  return result;
}

/**
 * @description 获取图片访问地址
 * @param url {String} 图片路径
 * @param $vm {Vue} Vue实力
 */
export function getImageFullPath(url, $vm) {
  let reg = /^(\/\/|http|https).+$/;
  if(reg.test(url)) return url;
  if (Object.prototype.toString.call(url) !== '[object String]' || url === '') {
    console.error('传入的路径（path）非字符串类型，请确认路径是否正确');
    //throw new Error('传入的路径（path）非字符串类型，请确认路径是否正确');
  }
  let index = stringToNumber(url) % 6;
  let doMain = $vm.$setting.cdnBaseUrl.replace('@index@', index === 0 ? '' : index);
  return `${doMain}${url}`;
}

export default {
  methods: {
    ...mapActions('oss', [
      'getOssSign'
    ]),

    /**
     * @description 获取富文本上传配置
     * @returns {{}}
     */
    getImageConfig(){
      return {
        sort: true,
        maxlen: 100,
        action: 'aliyun',
        qiniuCdn: 'aliyun',
        size: 5,
        tipsformet: '上传文件格式：@imageType@，不超过@size@MB.',
        uploadType: 'aliyun',
        type: ['jpg', 'png', 'jpeg', 'gif']
      }
    },

    /**启动上传图片*******=======================================*/
    /**
     * @description 上传到本地服务器成功返回值时刻触发，设置url字段
     */
    handleApiSuccessUrl(result, resolve) {
      resolve(result.data['ObjectURL'])
    },

    /**
     * @description 上传参数设置
     * @param file
     * @param resolve
     */
    handleGetParamsAndHeader(file, resolve) {

      // resolve({
      //   params: {
      //     token: genUpToken({
      //       accoutKey: 'bP3Ca5dtSJBNaWwMkihfhuE30CbAZnYrNzQm6eMN',
      //       serviceKey: 'pPNgWwRL3_Jlj7cPtpYbkhXn01EOZTtUhOs3NqZM',
      //       webSiteName: 'e56buystatic',
      //       staticUrl: 'http://static.e56buy.com',
      //     }),
      //     key: 'Xd' + this.$xdHelper.randomChar(30)
      //   }
      // });

      /**需要自己实现接口**/
      this.getOssSign({name: file.name})
        .then((res) => {
          let OSSAccessKeyId = res.data['id'];
          let cdnUrl = res.data['cdn_url']
          delete res.data['id'];
          delete res.data['cdn_url'];
          resolve({
            params: {
              ...res.data,
              OSSAccessKeyId: OSSAccessKeyId,
              name: file.name,
              cdnUrl: cdnUrl,
              success_action_status: 200
            }
          })
        })
        .catch(this.$xdLog.catch)
    },

    /**
     * @description 上传到私有桶参数设置
     * @param file
     * @param resolve
     */
    handlePrivateGetParamsAndHeader(file, resolve) {
      /**需要自己实现接口**/
      this.getOssSign({name: file.name, type: 'private'})
        .then((res) => {
          let OSSAccessKeyId = res.data['id']
          let cdnUrl = res.data['cdn_url']
          delete res.data['id']
          delete res.data['cdn_url']
          resolve({
            params: {
              ...res.data,
              OSSAccessKeyId: OSSAccessKeyId,
              name: file.name,
              cdnUrl: cdnUrl,
              success_action_status: 200
            }
          })
        })
        .catch(this.$xdLog.catch)
    },

    handleSuccess(res) {
      console.log('handleSuccess', res, this)
    },

    /**启动上传图片*******=======================================*/
    getImageFullPath(url){
      return getImageFullPath(url, this);
    },

  }
}

