'use strict'

module.exports = {
  name: 'enterprise_buy',
  title: '集采单管理',
  vuex: true,
  model: [
    {
      title: '集采单管理 - 列表',
      mapFn: "purchaseMainOrder",
      isPublic: true,
      // #ifdef admin
      path: '/wholesale-admin/v1/purchase-main-order',
      // #endif
      // #ifdef partner-wholesale
      path: '/wholesale-partner/v1/purchase-main-order',
      // #endif
      // #ifdef oa-finance
      path: '/wholesale-partner/v1/finance/purchase-main-order',
      // #endif
      isRule: false,
      data: {
        filter: ['filter', 'Object', '非必填'],
        page_size: ['每页', 'String', '必填'],
        page_token: ['页数', 'String', '必填'],
      },
      resultKey: "data",
      disabled: true,
      role: '@@@.@@@.PURCHASE_MAIN_ORDER',
    },
    {
      title: '集采主单详情',
      mapFn: "purchaseMainOrderInfo",
      isPublic: true,
      // #ifdef admin
      path: '/wholesale-admin/v1/purchase-main-order/:purchase_main_order_id',
      // #endif
      // #ifdef partner-wholesale
      path: '/wholesale-partner/v1/purchase-main-order/:purchase_main_order_id',
      // #endif
      // #ifdef oa-finance
      path: '/wholesale-partner/v1/finance/purchase-main-order/:purchase_main_order_id',
      // #endif
      isRule: false,
      params: {
        purchase_main_order_id: ['purchase_main_order_id', 'String', '非必填'],
      },
      resultKey: "data",
      disabled: true,
      role: '@@@.@@@.PURCHASE_MAIN_ORDER_GET',
    },
    {
      title: '订单主单详情',
      mapFn: "mainOrderDetail",
      isPublic: true,
      // #ifdef admin
      path: '/order-admin/v1/customer-service/main-detail',
      // #endif
      // #ifdef oa-finance partner-wholesale
      path: '/wholesale-partner/v1/order/main-order/detail',
      // #endif
      isRule: false,
      params: {
        main_order_id: ['main_order_id', 'String', '必填'],
      },
      resultKey: "data",
      disabled: true,
      role: '@@@.@@@.MAIN_ORDER_DETAIL',
    },
    {
      title: '切换标签',
      mapFn: "tabItems",
      isPublic: true,
      // #ifdef admin partner-wholesale
      path: '/wholesale-public/v1/tab/items',
      // #endif
      // #ifdef oa-finance
      path: '/wholesale-public/v1/finance-tab/items',
      // #endif
      isRule: false,
      params: {},
      resultKey: "data",
      disabled: true,
    },
    {
      title: '集采单接单',
      mapFn: "purchaseMainOrderReceive",
      path: '/wholesale-partner/v1/purchase-main-order/:purchase_main_order_id/receive',
      isRule: false,
      params: {
        purchase_main_order_id: ['purchase_main_order_id', 'String', '必填'],
      },
      resultKey: "data",
      disabled: true,
      method:'put',
      role: '@@@.@@@.PURCHASE_MAIN_ORDER_RECEIVE',
    },
    {
      title: '集采单取消',
      mapFn: "purchaseMainOrderCancel",
      isPublic: true,
      // #ifdef admin
      path: '/wholesale-admin/v1/purchase-main-order/:purchase_main_order_id/order-status',
      // #endif
      // #ifdef oa-finance partner-wholesale
      path: '/wholesale-partner/v1/purchase-main-order/:purchase_main_order_id/cancel',
      // #endif
      isRule: false,
      params: {
        purchase_main_order_id: ['purchase_main_order_id', 'String', '必填'],
      },
      resultKey: "data",
      disabled: true,
      method: 'put',
      role: '@@@.@@@.PURCHASE_MAIN_ORDER_CANCEL',
    },
    {
      title: '超管-集采单确认价格',
      mapFn: "supplierSettlementAmountBatch",
      path: '/wholesale-admin/v1/purchase-sub-order/supplier-settlement-amount/batch',
      isRule: false,
      data: {
        purchase_main_order_id: ['purchase_main_order_id', 'String', '必填'],
        items: ['items', 'Array', '必填'],
      },
      resultKey: "data",
      disabled: true,
      method: 'put',
      role: '@@@.@@@.SUPPLIER_SETTLEMENT_AMOUNT_BATCH',
    },
    {
      title: '集采单确认主单价格',
      mapFn: "purchaseMainOrderConfirmAmount",
      path: '/wholesale-partner/v1/purchase-main-order/:purchase_main_order_id/confirm-amount',
      isRule: false,
      params: {
        purchase_main_order_id: ['purchase_main_order_id', 'String', '必填'],
      },
      resultKey: "data",
      disabled: true,
      method: 'put',
      role: '@@@.@@@.PURCHASE_MAIN_ORDER_CONFIRM_AMOUNT',
    },
    {
      title: '集采单确定买家支付',
      mapFn: "purchaseMainOrderConfirmPaid",
      path: '/wholesale-partner/v1/purchase-main-order/:purchase_main_order_id/confirm-consumer-paid',
      isRule: false,
      params: {
        purchase_main_order_id: ['purchase_main_order_id', 'String', '必填'],
      },
      resultKey: "data",
      disabled: true,
      method: 'put',
      role: '@@@.@@@.PURCHASE_MAIN_ORDER_CONFIRM_CONSUMER_PAID',
    },
    {
      title: '集采单确定加盟商支付',
      mapFn: "purchaseMainOrderConfirmPartnerPaid",
      path: '/wholesale-partner/v1/purchase-main-order/:purchase_main_order_id/confirm-partner-paid',
      isRule: false,
      params: {
        purchase_main_order_id: ['purchase_main_order_id', 'String', '必填'],
      },
      resultKey: "data",
      disabled: true,
      method: 'put',
      role: '@@@.@@@.PURCHASE_MAIN_ORDER_CONFIRM_PARTNER_PAID',
    },
    {
      title: '订单供货商列表',
      mapFn: "purchaseMainOrderSuppliers",
      path: '/wholesale-partner/v1/purchase-main-order/:purchase_main_order_id/suppliers',
      isRule: false,
      params: {
        purchase_main_order_id: ['purchase_main_order_id', 'String', '必填'],
      },
      resultKey: "data",
      disabled: true,
      role: '@@@.@@@.PURCHASE_MAIN_ORDER_SUPPLIERS',
    },
    {
      title: '上传加盟商发票',
      mapFn: "purchaseMainOrderPartnerUpload",
      path: '/wholesale-partner/v1/purchase-main-order/:purchase_main_order_id/upload-partner-invoice',
      isRule: false,
      params: {
        purchase_main_order_id: ['purchase_main_order_id', 'String', '必填'],
        invoice_url: ['invoice_url', 'String', '必填'],
      },
      resultKey: "data",
      disabled: true,
      method: 'put',
      role: '@@@.@@@.UPLOAD_PARTNER_INVOICE',
    },
    {
      title: '上传供应商发票',
      mapFn: "purchaseMainOrderSupplierUpload",
      path: '/wholesale-partner/v1/purchase-main-order/:purchase_main_order_id/upload-supplier-invoice',
      isRule: false,
      params: {
        purchase_main_order_id: ['purchase_main_order_id', 'String', '必填'],
        items: ['items', 'Array', '必填'],
      },
      resultKey: "data",
      disabled: true,
      method: 'put',
      role: '@@@.@@@.UPLOAD_SUPPLIER_INVOICE',
    },
    {
      title: '更新主单价格-用户结算价格',
      mapFn: "userSettlementAmount",
      path: '/wholesale-partner/v1/purchase-main-order/:purchase_main_order_id/user-settlement-amount',
      isRule: false,
      params: {
        purchase_main_order_id: ['purchase_main_order_id', 'String', '必填'],
        amount: ['amount', 'String', '必填'],
      },
      resultKey: "data",
      disabled: true,
      method: 'put',
      role: '@@@.@@@.USER_SETTLEMENT_AMOUNT',
    },
    {
      title: '更新商品价格-用户结算价格',
      mapFn: "userSettlementPrice",
      path: '/wholesale-partner/v1/purchase-main-order/:purchase_main_order_id/user-settlement-price',
      isRule: false,
      params: {
        purchase_main_order_id: ['purchase_main_order_id', 'String', '必填'],
        items: ['items', 'Array', '必填'],
      },
      resultKey: "data",
      disabled: true,
      method: 'put',
      role: '@@@.@@@.USER_SETTLEMENT_PRICE',
    },
    {
      title: '查看主单真实联系信息',
      mapFn: "mainOrderContactWh",
      isPublic: true,
      // #ifdef admin
      path: '/order-admin/v1/customer-service/contact',
      // #endif
      // #ifdef oa-finance partner-wholesale
      path: '/wholesale-partner/v1/order/main-order/contact',
      // #endif
      isRule: false,
      params: {
        main_order_id: ['main_order_id', 'String', '必填'],
      },
      resultKey: "data",
      disabled: true,
      role: '@@@.@@@.MAIN_ORDER_CONTACT',
    },
    {
      title: '查看主单包裹轨迹',
      mapFn: "logisticsMainOrderPackageTrackWh",
      isPublic: true,
      // #ifdef admin
      path: '/order-admin/v1/customer-service/package-track',
      // #endif
      // #ifdef oa-finance partner-wholesale
      path: '/wholesale-partner/v1/logistics-main-order/package-track',
      // #endif
      isRule: false,
      params: {
        main_order_id: ['main_order_id', 'String', '必填'],
        package_id: ['package_id', 'String', '必填'],
      },
      resultKey: "data",
      disabled: true,
      role: '@@@.@@@.LOGISTICS_MAIN_ORDER_PACKAGE_TRACK',
    },
    {
      title: '操作记录主单',
      mapFn: "mainOrderChangeLogsWh",
      isPublic: true,
      // #ifdef admin
      path: '/order-admin/v1/order/change-logs',
      // #endif
      // #ifdef oa-finance partner-wholesale
      path: '/wholesale-partner/v1/main-order/change-logs',
      // #endif
      isRule: false,
      params: {
        main_order_id: ['main_order_id', 'String', '必填'],
        page_size: ['page_size', 'Number', '必填'],
        page_token: ['page_token', 'String', '必填'],
      },
      resultKey: "data",
      disabled: true,
      role: '@@@.@@@.MAIN_ORDER_CHANGE_LOGS',
    },
    {
      title: '操作记录子单',
      mapFn: "subOrderChangeLogsWh",
      path: '/wholesale-partner/v1/sub-order/change-logs',
      isRule: false,
      params: {
        sub_order_id: ['sub_order_id', 'String', '必填'],
        page_size: ['page_size', 'Number', '必填'],
        page_token: ['page_token', 'String', '必填'],
      },
      resultKey: "data",
      disabled: true,
      role: '@@@.@@@.SUB_ORDER_CHANGE_LOGS',
    },
    {
      mapFn: 'syncPackageTrackWh',
      isRule: false,
      title: '同步物流信息',
      isPublic: true,
      // #ifdef admin
      path: '/order-admin/v1/logistics-sub-order/sync-package-track',
      // #endif
      // #ifdef oa-finance partner-wholesale
      path: '/order-partner/v1/logistics-sub-order/sync-package-track',
      // #endif
      data: {
        order_package_id: ['order_package_id', 'String', '必选'],
        express_number: ['express_number', 'String', '必选'],
        express_code: ['express_code', 'String', '必选'],
      },
      disabled: true,
      role: '@@@.@@@.LOGISTTICS_SUB_ORDER_SYNC_PACKAGE_TRACK',
    },
    {
      mapFn: 'recordPackageTrackWh',
      isRule: false,
      title: '自定义录入物流信息',
      isPublic: true,
      // #ifdef admin
      path: '/order-admin/v1/logistics-sub-order/record-package-track',
      // #endif
      // #ifdef oa-finance partner-wholesale
      path: '/order-partner/v1/logistics-sub-order/record-package-track',
      // #endif
      data: {
        package_id: ['package_id', 'String', '必选'],
        time: ['time', 'Number', '必选'],
        content: ['content', 'String', '必填'],
      },
      disabled: true,
      role: '@@@.@@@.LOGISTTICS_SUB_ORDER_RECORD_PACKAGE_TRACK',
    },
    {
      title: '集采-配置-获取加盟商税点',
      mapFn: "taxRatioConfigGet",
      path: '/wholesale-admin/v1/tax-ratio-config/get',
      isRule: false,
      params: {
        partner_id: ['partner_id', 'String', '必填'],
      },
      resultKey: "data",
      disabled: true,
      role: '@@@.@@@.TAX_RATIO_CONFIG_GET',
    },
    {
      title: '集采-配置-获取加盟商列表',
      mapFn: "taxRatioConfigList",
      path: '/wholesale-admin/v1/tax-ratio-config/list',
      isRule: false,
      params: {
        page_token: ['page_token', 'String', '必填'],
        page_size: ['page_size', 'String', '必填'],
      },
      resultKey: "data",
      disabled: true,
      role: '@@@.@@@.TAX_RATIO_CONFIG_LIST',
    },
    {
      title: '集采-配置-保存加盟商税点',
      mapFn: "taxRatioConfigSet",
      path: '/wholesale-admin/v1/tax-ratio-config/set',
      isRule: false,
      data: {
        partner_id: ['partner_id', 'Number', '必填'],
        tax_ratio: ['tax_ratio', 'Number', '必填'],
        status: ['status', 'String', '必填'],
      },
      resultKey: "data",
      disabled: true,
      role: '@@@.@@@.TAX_RATIO_CONFIG_SET',
    },
    {
      title: '生成订单',
      mapFn: "purchaseMainOrderCreateOrder",
      isPublic:true,
      path: '/wholesale-partner/v1/purchase-main-order/:purchase_main_order_id/create-order',
      isRule: false,
      data: {
        purchase_main_order_id: ['purchase_main_order_id', 'String', '必填'],
      },
      resultKey: "data",
      disabled: true,
      role: '@@@.@@@.PURCHASE_MAIN_ORDER_CREATE_ORDER',
    },
    {
      title: '集采-列表-操作按钮',
      mapFn: "purchaseListOperate",
      path: '',
      isRule: false,
      data: {},
      resultKey: "data",
      disabled: true,
      role: '@@@.@@@.PURCHASE_LIST_OPRERATE',
    },
    {
      title: '集采-详情-操作按钮',
      mapFn: "purchaseDetailOperate",
      path: '',
      isRule: false,
      data: {},
      resultKey: "data",
      disabled: true,
      role: '@@@.@@@.PURCHASE_DETAIL_OPRERATE',
    },
  ],
}
